@@ -1,19 +1,12 @@
+import requests
+
 try:
     # noinspection PyShadowingBuiltins
     from printlog import printlog as print
 except ImportError:
     pass
 
-try:
-    import gpio_cmds
-    print("Running on robot...")
-    emulate = False
-except ImportError:
-    print("Running in emulation mode...")
-    emulate = True
-
-
-target_drive_speed = 75
+from CV_Robot import is_Robot, robot_URL
 
 def forward():
     """
@@ -22,6 +15,9 @@ def forward():
     Runs emulated code if GPIO backend not found.
     """
     print("Driving forward...")
+    if is_Robot:
+        requests.get('http://' + robot_URL + '/forward')
+
 
 def backward():
     """
@@ -30,6 +26,8 @@ def backward():
     Runs emulated code if GPIO backend not found.
     """
     print("Driving backward...")
+    if is_Robot:
+        requests.get('http://' + robot_URL + '/backward')
 
 def left():
     """
@@ -38,6 +36,8 @@ def left():
     Runs emulated code if GPIO backend not found.
     """
     print("Turning left...")
+    if is_Robot:
+        requests.get('http://' + robot_URL + '/left')
 
 def right():
     """
@@ -46,6 +46,8 @@ def right():
     Runs emulated code if GPIO backend not found.
     """
     print("Turning right...")
+    if is_Robot:
+        requests.get('http://' + robot_URL + '/right')
 
 def stop():
     """
@@ -54,10 +56,12 @@ def stop():
     Runs emulated code if GPIO backend not found.
     """
     print("Stopping robot...")
+    if is_Robot:
+        requests.get('http://' + robot_URL + '/stop')
 
 def speed(val):
     """
     Sets driving speed to value specified
     """
-    global target_drive_speed
-    target_drive_speed = val
\ No newline at end of file
+    if is_Robot:
+        requests.get('http://' + robot_URL + '/speed?val=' + str(val))
\ No newline at end of file
